import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)
/**
 * Author: Nicolas Kammerdiener
 * Chapter 4 
 * Actor: Crab
 */

/**
 * This class defines a crab. Crabs live on the beach.
 */
public class Crab extends Animal
{
    private GreenfootImage image1;
    private GreenfootImage image2;
    private int wormsEaten; 
    private int delay; 
    
    /**
     * Creates a crab and uses its two images. 
     */
    public Crab()
    {
        image1 = new GreenfootImage("crab.png");
        image2 = new GreenfootImage("crab2.png");
        setImage(image1);
        wormsEaten=0; 
        delay=0; //Sets delay for worm equal to 0
    }
    
    /**
     * Switches the two images.
     */
    public void switchImage()
    {
        Greenfoot.delay(3);
        if (getImage() == image1)
        {
            setImage(image2);
        }
        else
        {
            setImage(image1);
        }
    }
    
    public void act()
    {
        checkKeypress(); 
        lookForWorm();
        switchImage();
        if (delay>20)
        {
            World w = getWorld();
            CrabWorld cw = (CrabWorld)w;
            cw.addWorm();
            delay=0;
        }
        else
        {
            delay++;
        }    
    }

    /**
     * Check whether we have stumbled upon a worm
     * If we have, eat it. If not, do nothing. 
     * Once eight worms have been eaten it plays a fanfare. 
     */
    public void lookForWorm()
    {
        if (canSee(Worm.class))
        {
            eat(Worm.class);
            Greenfoot.playSound("slurp.wav");
            wormsEaten = wormsEaten+1;
            if (wormsEaten == 8)
            {
                Greenfoot.playSound("fanfare.wav");
                Greenfoot.stop(); 
            }
        }
    }

    /**
     * This checks to see whether a key is pressed.
     * If it is it turns according to which key is pressed 
     */
    public void checkKeypress()
    {
        if (Greenfoot.isKeyDown("up"))
        {
            move();
        }
        
        if (Greenfoot.isKeyDown("left"))
        {
            turn(-4);
        }

        if (Greenfoot.isKeyDown("right"))
        {
            turn(4);
        }
    }
}

